# frozen_string_literal: true

#--
# wwwjdic
# © 2014-2021 Marco Bresciani
#
# This file is part of wwwjdic.
#
# wwwjdic is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# wwwjdic is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with wwwjdic. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2014-2021 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative '../lib/wwwjdic'

i = 0

# Create the WWWJDic object
puts '=========================================='
puts "BASICS #{i}: Create the WWWJDic object."
puts 'irb(main):001:0> a_wwwjdic = WWWJDic::breener'
a_wwwjdic = WWWJDic.breener
puts '------------------------------------------'
puts
i += 1

# Print the (default) dictionary
# Jpn-Eng General (EDICT)
puts '=========================================='
puts "BASICS #{i}: Print the (default) dictionary [Jpn-Eng General (EDICT)]."
puts 'irb(main):001:0> puts a_wwwjdic.dictionary'
puts a_wwwjdic.dictionary
puts '------------------------------------------'
puts
i += 1

# Print the (default) server URI.
# http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?
puts '=========================================='
puts "BASICS #{i}'. Print the (default) server URI [http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?]."
puts 'irb(main):001:0> puts a_wwwjdic.server'
puts a_wwwjdic.server
puts '------------------------------------------'
puts
i += 1

# Print the current (default) WWWJDic configuration URL.
# http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1M
puts '=========================================='
puts "BASICS #{i}: Print the current (default) WWWJDic configuration URL [http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1M]."
puts 'irb(main):001:0> puts a_wwwjdic'
puts a_wwwjdic
puts '------------------------------------------'
puts
i += 1

# Change the server value to Monash University one.
puts '=========================================='
puts "BASICS #{i}: Change the server value to Monash University one."
puts 'irb(main):001:0> a_wwwjdic.server = :monash'
a_wwwjdic.server = :monash
puts '------------------------------------------'
puts
i += 1

# Print the (currently set) server.
# http://www.csse.monash.edu.au/~jwb/cgi-bin/wwwjdic.cgi?
puts '=========================================='
puts "BASICS #{i}: Print the (currently set) server  [http://www.csse.monash.edu.au/~jwb/cgi-bin/wwwjdic.cgi?]."
puts 'irb(main):001:0> puts a_wwwjdic.server'
puts a_wwwjdic.server
puts '------------------------------------------'
puts
i += 1

# Print the WWWJDic configuration URL with currently set configuration.
# http://www.csse.monash.edu.au/~jwb/cgi-bin/wwwjdic.cgi?1M
puts '=========================================='
puts "BASICS #{i}: Print the WWWJDic configuration URL with currently set configuration [http://www.csse.monash.edu.au/~jwb/cgi-bin/wwwjdic.cgi?1M]."
puts 'irb(main):001:0> puts a_wwwjdic'
puts a_wwwjdic
puts '------------------------------------------'
puts
i += 1

# Reset the configuration to default values.
# (http://www.csse.monash.edu.au/~jwb/cgi-bin/wwwjdic.cgi?1M)
puts '=========================================='
puts "BASICS #{i}: Reset the configuration to default values."
puts 'irb(main):001:0> a_wwwjdic.reset'
a_wwwjdic.reset
puts '------------------------------------------'
puts
i += 1

# Change the language value to Japanese-Italian one.
puts '=========================================='
puts "BASICS #{i}: Change the language value to Japanese-Italian one."
puts "irb(main):001:0> a_wwwjdic.dictionary = 'Japanese-Italian'"
a_wwwjdic.dictionary = 'Japanese-Italian'
puts '------------------------------------------'
puts
i += 1

# Print the current WWWJDic configuration URL.
# http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?OM
puts '=========================================='
puts "BASICS #{i}: Print the current WWWJDic configuration URL [http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?OM]."
puts 'irb(main):001:0> puts a_wwwjdic'
puts a_wwwjdic
puts '------------------------------------------'
puts
