# frozen_string_literal: true

#--
# wwwjdic
# © 2014-2021 Marco Bresciani
#
# This file is part of wwwjdic.
#
# wwwjdic is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# wwwjdic is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with wwwjdic. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2014-2021 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative '../lib/wwwjdic'

i = 0

# Create the WWWJDic object
puts '=========================================='
puts "URI #{i}: Create the WWWJDic object."
puts 'irb(main):001:0> a_wwwjdic = WWWJDic::breener'
a_wwwjdic = WWWJDic.breener
puts '------------------------------------------'
puts
i += 1

# rubocop:disable Style/AsciiComments
# Compute the default basic URI to translate '翻訳' in English
# rubocop:enable Style/AsciiComments
# http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1MUQ%E7%BF%BB%E8%A8%B3
puts '=========================================='
puts "URI #{i}: Compute the default basic URI to translate '翻訳' in English (http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1MUQ%E7%BF%BB%E8%A8%B3)."
puts "irb(main):001:0> a_wwwjdic.uri '翻訳'"
puts a_wwwjdic.uri '翻訳'
puts '------------------------------------------'
puts
i += 1

# rubocop:disable Style/AsciiComments
# Compute the default raw URI to translate '翻訳' in English
# rubocop:enable Style/AsciiComments
# http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1ZUQ%E7%BF%BB%E8%A8%B3
puts '=========================================='
puts "URI #{i}: Compute the default raw URI to translate '翻訳' in English (http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1ZUQ%E7%BF%BB%E8%A8%B3)."
puts "irb(main):001:0> a_wwwjdic.raw_uri '翻訳'"
puts a_wwwjdic.raw_uri '翻訳'
puts '------------------------------------------'
puts
i += 1

# rubocop:disable Style/AsciiComments
# Compute the default JSON URI to translate '翻訳' in English
# {"翻訳":"http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1MUQ%E7%BF%BB%E8%A8%B3"}
# rubocop:enable Style/AsciiComments
puts '=========================================='
puts "URI #{i}: Compute the default JSON URI to translate '翻訳' in English ({\"翻訳\":\"http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?1MUQ%E7%BF%BB%E8%A8%B3\"})."
puts "irb(main):001:0> a_wwwjdic.json_uri '翻訳'"
puts a_wwwjdic.json_uri '翻訳'
puts '------------------------------------------'
puts
i += 1

# rubocop:disable Style/AsciiComments
# Compute the default basic URI to translate '翻訳' in Italian
# rubocop:enable Style/AsciiComments
# http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?OMUQ%E7%BF%BB%E8%A8%B3
puts '=========================================='
puts "URI #{i}: Compute the default basic URI to translate '翻訳' in Italian (http://www.edrdg.org/cgi-bin/wwwjdic/wwwjdic.cgi?OMUQ%E7%BF%BB%E8%A8%B3)."
puts "irb(main):001:0> a_wwwjdic.uri '翻訳', dict: 'Japanese-Italian'"
puts a_wwwjdic.uri '翻訳', dict: 'Japanese-Italian'
puts '------------------------------------------'
puts
i += 1

# rubocop:disable Style/AsciiComments
# Compute the default basic URI to translate '翻訳' in German, through Monash university URI
# rubocop:enable Style/AsciiComments
# http://nihongo.monash.edu/cgi-bin/wwwjdic?GMUQ%E7%BF%BB%E8%A8%B3
puts '=========================================='
puts "URI #{i}: Compute the default basic URI to translate '翻訳' in German, through Monash university URI (http://nihongo.monash.edu/cgi-bin/wwwjdic?GMUQ%E7%BF%BB%E8%A8%B3)."
puts "irb(main):001:0> a_wwwjdic.uri '翻訳', dict: 'Japanese-German (WaDoku)', server: :monash"
puts a_wwwjdic.uri '翻訳', dict: 'Japanese-German (WaDoku)', server: :monash
puts '------------------------------------------'
puts
