# frozen_string_literal: true

#--
# wwwjdic
# © 2014-2021 Marco Bresciani
#
# This file is part of wwwjdic.
#
# wwwjdic is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# wwwjdic is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with wwwjdic. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2014-2021 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative '../../test_helper'

def test_raise_error_param(param)
  it "shall raise and error for parameter '#{param}'" do
    assert_raises ArgumentError do
      subject.parse param
    end
  end
end

def test_wrong_name
  it 'shall raise an error when wrong dictionary name' do
    assert_raises ArgumentError do
      subject.parse 'test'
    end
  end
end

def test_wrong_code
  it 'shall raise an error when wrong dictionary code' do
    assert_raises ArgumentError do
      subject.parse 'Z'
    end
  end
end

def test_invalid_param
  describe 'when provided and invalid parameter' do
    [nil, '', 42].each(&method(:test_raise_error_param))

    test_wrong_name

    test_wrong_code
  end
end

def test_dictionary_code
  describe 'when using the dictionary code/number' do
    WWWJDic::DICTIONARY_CODES.each do |value|
      it "shall return '#{value}' when parameter is '#{value}'" do
        _(subject.parse(value)).must_equal value
      end
    end
  end
end

def test_dictionary_name
  describe 'when using the dictionary name' do
    WWWJDic::DICTIONARY_NAMES.each do |value|
      translated = WWWJDic::DICTS_BY_NAMES[value]
      it "shall return '#{translated}' when parameter is '#{value}'" do
        _(subject.parse(value)).must_equal translated
      end
    end
  end
end

describe WWWJDic::WWWJDic do
  describe 'when using a parser' do
    include WWWJDic::ParsableDuckType

    before do
      @parser = subject
      I18n.load_path = Dir[File.join(File.dirname(__FILE__), '../locales/', '*.yml')]
    end

    subject { WWWJDic::Parsers::Dict.new }

    test_invalid_param

    test_dictionary_code

    test_dictionary_name
  end
end
