# frozen_string_literal: true

#--
# wwwjdic
# © 2014-2021 Marco Bresciani
#
# This file is part of wwwjdic.
#
# wwwjdic is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or (at your
# option) any later version.
#
# wwwjdic is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
# for more details.
#
# You should have received a copy of the GNU General Public License
# along with wwwjdic. If not, see <http://www.gnu.org/licenses/>.
#
# SPDX-FileCopyrightText: 2014-2021 Marco Bresciani
#
# SPDX-License-Identifier: GPL-3.0-or-later
#++

require_relative '../../test_helper'

def test_no_raise
  it 'does not raise an ArgumentError when value is nil or in the array' do
    all_methods = { raiser_downcase: [[nil, nil], ['value', ['value']]],
                    raiser_to_i: [[nil, nil], ['42', [42]]] }

    all_methods.each_key do |method_name|
      a_method = method method_name
      all_methods[method_name.to_sym].each do |params|
        a_method.call 'error.value', params[0], params[1]
      end
    end
  end
end

def test_raise
  it 'raises ArgumentError when value is not nil and not in the array' do
    all_methods = { raiser_downcase: ['value', ['no value']],
                    raiser_to_i: ['42', [47]] }

    all_methods.each_key do |method_name|
      a_method = method method_name
      assert_raises ArgumentError do
        a_method.call 'error.value', all_methods[method_name.to_sym][0], all_methods[method_name.to_sym][1]
      end
    end
  end
end

def test_raiser
  describe 'when running any raiser method' do
    test_no_raise

    test_raise
  end
end

describe WWWJDic::Utils::Raisers do
  include WWWJDic::Utils::Raisers
  all_methods = nil

  before do
    I18n.load_path = Dir[File.join(File.dirname(__FILE__), '../locales/', '*.yml')]
    I18n.locale = 'it'
    all_methods = {}
  end

  test_raiser
end
